#ifndef NT2_INCLUDE_FUNCTIONS_MAGIC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MAGIC_HPP_INCLUDED

#include <nt2/gallery/include/functions/magic.hpp>

#endif
